@@ -9,7 +9,7 @@ Types::Core - Core types defined as tests and literals (ease of use)
 
 =head1 VERSION
 
-Version "0.1.6";
+Version "0.1.7";
 
 =cut
 
@@ -19,8 +19,9 @@ Version "0.1.6";
 	use strict;
 	use warnings;
 	use mem;
-	our $VERSION='0.1.6';
+	our $VERSION='0.1.7';
 
+# 0.1.7 - Attempt to fix a parsing problem in 5.8.9
 # 0.1.6 - Needed to split a statement that parsed in a different order under
 #         5.8.x
 # 0.1.5 - Added code and test case to handle type-named classes
@@ -93,7 +94,8 @@ Version "0.1.6";
 
 			eval '# line ' . __LINE__ .' '. __FILE__ .' 
 			sub _type ($) { Scalar::Util::reftype($_[0]) }
-			sub _isatype ($$) { (typ($_[0])//"") eq ($_[1]//"") ? $_[0] : undef };
+			sub _isatype ($$) { 
+				(_type($_[0]) || "") eq ( $_[1] || "") ? $_[0] : undef };
 			sub blessed ($) { Scalar::Util::blessed($_[0]) ? $_[0] : undef }';
 
 			$@ && die "_isatype eval(1): $@";
